SSRI

## Welcome to SSRI

Let's say we had a footer below, that we wanted to be able to include in a bunch of different HTML files (in this simple example we are including it in `index.html` and `secondaryPage.html` which is here)

We could copy the HTML code for my footer into each file, but what if we have a lot of files, and what happens if we need to update the footer later on? Seems annoying and like it would take a while.

Instead, we could just put the code into a file called "footer.html", and put a comment in our html file (`<!-- include file="footer.html" -->`), that includes it in our file for us. This means it shares some of the same benefits of regular SSI, one of which is if something goes wrong, it will only be displayed as a comment, and hence won't be shown on the webpage, but will be show in the dev tools, helping with debugging.